aboutsummaryrefslogtreecommitdiffstats
path: root/src/net/ipv4.c
diff options
context:
space:
mode:
authorMichael Brown <mcb30@ipxe.org>2011-07-15 18:48:46 +0100
committerMichael Brown <mcb30@ipxe.org>2011-07-15 18:48:46 +0100
commita667bf044a37f9e96830f1f35627829860f7019f (patch)
treefabf3420f244fd35ed3576169db8cf0cd706dd9f /src/net/ipv4.c
parent69b7d57265679d76e26581d034e8f8ab5168bb27 (diff)
downloadipxe-a667bf044a37f9e96830f1f35627829860f7019f.tar.gz
[netdevice] Allow link layer to report broadcast/multicast packets via pull()
Allow the link layer to directly report whether or not a packet is multicast or broadcast at the time of calling pull(), rather than relying on heuristics to determine this at a later stage. Signed-off-by: Michael Brown <mcb30@ipxe.org>
Diffstat (limited to 'src/net/ipv4.c')
-rw-r--r--src/net/ipv4.c13
1 files changed, 8 insertions, 5 deletions
diff --git a/src/net/ipv4.c b/src/net/ipv4.c
index 5bb48f61c..01eca09d8 100644
--- a/src/net/ipv4.c
+++ b/src/net/ipv4.c
@@ -381,10 +381,12 @@ static int ipv4_tx ( struct io_buffer *iobuf,
/**
* Process incoming packets
*
* @v iobuf I/O buffer
* @v netdev Network device
* @v ll_dest Link-layer destination address
* @v ll_source Link-layer destination source
*
* This function expects an IP4 network datagram. It processes the headers
* and sends it to the transport layer.
@@ -392,7 +394,8 @@ static int ipv4_tx ( struct io_buffer *iobuf,
static int ipv4_rx ( struct io_buffer *iobuf,
struct net_device *netdev __unused,
const void *ll_dest __unused,
- const void *ll_source __unused ) {
+ const void *ll_source __unused,
+ unsigned int flags __unused ) {
struct iphdr *iphdr = iobuf->data;
size_t hdrlen;
size_t len;
@@ -381,10 +381,12 @@ static int ipv4_tx ( struct io_buffer *iobuf,
* Process incoming packets
*
- * @v iobuf I/O buffer
- * @v netdev Network device
- * @v ll_dest Link-layer destination address
- * @v ll_source Link-layer destination source
+ * @v iobuf I/O buffer
+ * @v netdev Network device
+ * @v ll_dest Link-layer destination address
+ * @v ll_source Link-layer destination source
+ * @v flags Packet flags
+ * @ret rc Return status code
*
* This function expects an IP4 network datagram. It processes the headers